@@ -664,10 +664,13 @@ def compute_extensive_kpis(data_df = None, strat = None):
 
     for nb_month in [1,3,6]:
         back_date = data_df.index[-1] + pd.DateOffset(months=-1*nb_month)
-
-        past_values = data_df.loc[back_date]
-        return_to_date = (current_values[strat] - past_values[strat])/past_values[strat]
-        results[f'return_{nb_month}_month'] = return_to_date
+        try :
+            past_values = data_df.loc[back_date]
+            return_to_date = (current_values[strat] - past_values[strat])/past_values[strat]
+            results[f'return_{nb_month}_month'] = return_to_date
+        except Exception as e:
+            print(f'trouble {e}')
+            results[f'return_{nb_month}_month'] = np.nan
 
     past_returns = pd.Series(results)
 
